@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.23';
+our $VERSION = '1.25';
 
 use Lingua::EN::Inflect 'PL';
 use File::Spec ();
@@ -19,7 +19,20 @@ use Class::Tiny {
 
 our %Wordlist; ## no critic ( Variables::ProhibitPackageVars )
 
-sub _copy_wordlist { return { %Wordlist } }
+sub _copy_wordlist {
+    my %copy;
+
+    # %Wordlist can be accessed externally, and users will often add terms in
+    # encoded form
+    for my $word ( keys %Wordlist ) {
+        my $decoded_word = $word;
+        # if it was already decoded, this should do nothing
+        utf8::decode($decoded_word);
+        $copy{$decoded_word} = 1;
+    }
+
+    return \%copy;
+}
 
 BEGIN {
     my $file;
@@ -53,6 +66,7 @@ sub learn_stopwords {
 
     while ( $text =~ m<(\S+)>g ) {
         my $word = $1;
+        utf8::decode($word);
         if ( $word =~ m/^!(.+)/s ) {
             # "!word" deletes from the stopword list
             my $negation = $1;
@@ -178,7 +192,7 @@ Pod::Wordlist - English words that come up in Perl documentation
 
 =head1 VERSION
 
-version 1.23
+version 1.25
 
 =head1 DESCRIPTION
 
